"""Operating system utilities.

Subprocess execution with enhanced error logging and command path discovery.

Features:
    - Subprocess execution: Enhanced subprocess.run() with error logging
    - Command discovery: Find executable paths with optional error raising
"""
