"""pyrig - A Python toolkit to rig up your project.

Opinionated Python project toolkit that standardizes and automates project setup,
configuration, and development workflows.

Subpackages:
    src: Runtime utilities (introspection, CLI, Git, string, testing and more)
    dev: Development tools (config generators, builders, CLI commands, testing and more)
    resources: Static resource files (templates, licenses)
"""
